"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "generate", {
    enumerable: true,
    get: ()=>generate
});
const _middlewares = require("../middlewares");
const _utils = require("../utils");
const _chalk = /*#__PURE__*/ _interopRequireDefault(require("chalk"));
const _commander = require("commander");
const _fs = require("fs");
const _inquirer = /*#__PURE__*/ _interopRequireDefault(require("inquirer"));
const _nodePlop = /*#__PURE__*/ _interopRequireDefault(require("node-plop"));
const _path = require("path");
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
const generate = (0, _commander.createCommand)().name('generate').description('generate different types of files based on sanitized templates').addArgument(new _commander.Argument('[type]', 'type of file you want to generate')).option('--extract', 'extract the template cli to your project locally so you can edit/add generators and templates').action(async (type, options)=>{
    if (!await (0, _middlewares.checkLocation)()) return;
    if (options.extract) return extractPlopToLocal();
    const plop = await getPlopInstance();
    if (!plop) return _utils.logger.failure('Your TSCord version is unknown.\nYou may need to update the CLI in order to support the latest version of TSCord.');
    if (!type) type = await getTypeFromUser(plop);
    const generator = plop.getGenerator(type);
    if (!generator) return console.log(`Generator "${type}" not found!`);
    const inputs = await generator.runPrompts();
    const results = await generator.runActions(inputs);
    results.changes.forEach((change)=>{
        console.log(change.type, change.path);
    });
    results.failures.forEach((failure)=>{
        console.log(failure.type, failure.path);
    });
});
const getTypeFromUser = async (plop)=>{
    const generators = plop.getGeneratorList();
    const result = await _inquirer.default.prompt([
        {
            type: 'list',
            name: 'type',
            message: 'What do you want to generate?',
            choices: generators.sort((a, b)=>a.name.localeCompare(b.name)).map(({ name , description  })=>({
                    name: `${_chalk.default.greenBright(name)} - ${_chalk.default.gray.italic(description ?? plop.getGenerator(name)?.description)}`,
                    value: name
                })),
            loop: false
        }
    ]);
    return result.type;
};
const getPlopInstance = async ()=>{
    const localPlop = (0, _fs.existsSync)((0, _path.resolve)() + '/cli/plopfile.js');
    if (localPlop) return (0, _nodePlop.default)((0, _path.resolve)() + '/cli/plopfile.js');
    else {
        try {
            const tscordVersion = await (0, _utils.getTscordVersion)();
            return (0, _nodePlop.default)(`${__dirname}/../plop/${tscordVersion}/cli/plopfile.js`);
        } catch (err) {
            return null;
        }
    }
};
const extractPlopToLocal = async ()=>{
    const localPlop = (0, _fs.existsSync)((0, _path.resolve)() + '/cli/plopfile.js');
    if (localPlop) _utils.logger.failure('Template CLI is already extracted to your project');
    else {
        _utils.logger.newLine();
        const success = await (0, _utils.downloadPlopFromGithub)();
        if (success) _utils.logger.success('Template CLI extracted to your project');
        else _utils.logger.failure('Something went wrong while extracting the template CLI to your project');
    }
};
