"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "default", {
    enumerable: true,
    get: ()=>_default
});
const _config = require("../../config");
const _utils = require("../../utils");
const _chalk = /*#__PURE__*/ _interopRequireDefault(require("chalk"));
const _commander = require("commander");
const _fs = require("fs");
const _promises = require("fs/promises");
const _path = require("path");
const _simpleGit = /*#__PURE__*/ _interopRequireDefault(require("simple-git"));
const _spawnise = require("spawnise");
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
const git = (0, _simpleGit.default)();
const _default = (0, _commander.createCommand)().name('bot').description('init a discord bot based on the tscord template').argument('<name>', 'name of the bot').argument('[version]', 'specify the version of the template to use', 'latest').option('--no-deps', 'do not install dependencies').option('--no-git', 'do not setup git').option('--pnpm', 'use pnpm instead of npm').option('--yarn', 'use yarn instead of npm').action(async (name, version, options)=>{
    _utils.logger.newLine();
    _utils.logger.spinner.start('Downloading template...');
    // guards
    if ((0, _fs.existsSync)((0, _path.resolve)(name))) return _utils.logger.failure('A folder with this name already exists');
    // create the folder
    await (0, _promises.mkdir)(name);
    // download the template
    const success = await (0, _utils.downloadReleaseFromGithub)(name, _config.repositories.template, version);
    if (!success) {
        await (0, _promises.rmdir)(name);
        _utils.logger.failure('Failed to download the template' + (version !== 'latest' ? `\n  Version ${_chalk.default.bold(version)} does not exist` : ''));
        return;
    }
    // install dependencies
    if (options.deps) {
        _utils.logger.spinner.start('Installing dependencies...');
        const packageManager = options.pnpm ? 'pnpm' : options.yarn ? 'yarn' : 'npm';
        if (packageManager !== 'npm') await (0, _promises.rm)((0, _path.resolve)(name, 'package-lock.json'));
        await (0, _spawnise.spawn)(packageManager, [
            'install'
        ], {
            env: process.env,
            cwd: (0, _path.resolve)(name),
            stdio: 'ignore'
        });
    }
    // setup git
    if (options.git) {
        _utils.logger.spinner.text = 'Setup git...';
        await git.cwd((0, _path.resolve)(name));
        await git.init();
        await git.add('.');
        await git.commit('init project from barthofu/tscord');
    }
    _utils.logger.success(`Successfully initialized ${_chalk.default.bold(name)}!`);
});
