"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "default", {
    enumerable: true,
    get: ()=>_default
});
const _middlewares = require("../../middlewares");
const _utils = require("../../utils");
const _chalk = /*#__PURE__*/ _interopRequireDefault(require("chalk"));
const _commander = require("commander");
const _path = require("path");
const _spawnise = require("spawnise");
const _semver = /*#__PURE__*/ _interopRequireDefault(require("semver"));
const _config = require("../../config");
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
const _default = (0, _commander.createCommand)().name('install').description('install a plugin').argument('<name>', 'plugin name you want to install').action(async (rawName)=>{
    if (!await (0, _middlewares.checkLocation)()) return;
    _utils.logger.newLine();
    _utils.logger.spinner.start(`Downloading plugin ${_chalk.default.bold(rawName)}...`);
    // determine if its a link or a plugin name
    if (!(0, _utils.isUrl)(rawName)) {
        const version = rawName.split('@')[1] || 'latest';
        const name = rawName.split('@')[0];
        const localPlugin = await (0, _utils.getLocalPlugin)(name);
        if (localPlugin) return _utils.logger.failure(`Plugin ${_chalk.default.bold(name)} already installed.`);
        const remotePlugin = await (0, _utils.getPluginFromMonorepo)(name, version);
        if (remotePlugin) {
            const projectPackageJson = await (0, _utils.getPackageJson)();
            if (!_semver.default.satisfies(_semver.default.coerce(projectPackageJson.tscord.version), remotePlugin.tscordRequiredVersion)) return _utils.logger.failure(`Plugin ${_chalk.default.bold(name)} requires tscord version ${_chalk.default.bold(remotePlugin.tscordRequiredVersion)}, but you are using ${_chalk.default.bold(projectPackageJson.tscord.version)}.`);
            // download the plugin from the official repo
            const result = await (0, _utils.downloadPluginFromMonorepo)(name, 'src/plugins', {
                ..._config.repositories.plugins,
                branch: remotePlugin.commitHash || 'main'
            });
            if (!result) return _utils.logger.failure(`Failed to install ${_chalk.default.bold(rawName)}`);
            // download dependencies
            _utils.logger.spinner.start('Installing plugin dependencies...');
            const packageManager = await (0, _utils.getCurrentPackageManager)();
            await (0, _spawnise.spawn)(packageManager, [
                'install'
            ], {
                env: process.env,
                cwd: (0, _path.resolve)() + `/src/plugins/${name}/`,
                stdio: 'ignore'
            });
            if (result) _utils.logger.success(`Successfully installed ${rawName}`);
        } else _utils.logger.failure(`Plugin ${_chalk.default.bold(`${name}@${version}`)} not found.`);
    } else {
        _utils.logger.failure('Not implemented yet.');
    }
});
