"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "default", {
    enumerable: true,
    get: ()=>_default
});
const _utils = require("../../utils");
const _chalk = /*#__PURE__*/ _interopRequireDefault(require("chalk"));
const _commander = require("commander");
const _oneline = /*#__PURE__*/ _interopRequireDefault(require("oneline"));
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
const _default = (0, _commander.createCommand)().name('search').description('search for a plugin').argument('<query>', 'query you want to search').option('-s, --short', 'speed up search command by not showing extra information on plugins').option('-l, --limit <number>', 'limit the number of results', '10').action(async (query, options)=>{
    _utils.logger.newLine();
    // get all plugins from the monorepo
    const plugins = await (0, _utils.getPluginsFromMonorepo)();
    // filter the plugins by the query
    const results = plugins.filter((plugin)=>plugin.toLowerCase().includes(query.toLowerCase()));
    if (results.length > 0) _utils.logger.log(_chalk.default.underline(`Results for query '${_chalk.default.italic.bold(query)}':\n`));
    else return _utils.logger.failure('No results found.');
    for (const pluginName of results.slice(0, Number(options.limit))){
        const localPlugin = await (0, _utils.getLocalPlugin)(pluginName);
        const baseMessage = `◦${localPlugin ? _chalk.default.green(' [installed]') : ''} ${_chalk.default.bold.greenBright(pluginName)}`;
        if (!options.short) {
            const remotePlugin = await (0, _utils.getPluginFromMonorepo)(pluginName);
            if (remotePlugin) {
                const message = (0, _oneline.default)`
                        ${baseMessage}
                        (${remotePlugin.name} v${remotePlugin.version})
                        - ${_chalk.default.gray.italic(remotePlugin.description)}
                    `;
                _utils.logger.log(message);
            } else _utils.logger.log(baseMessage);
        } else {
            _utils.logger.log(baseMessage);
        }
    }
    _utils.logger.newLine();
});
