"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "default", {
    enumerable: true,
    get: ()=>_default
});
const _middlewares = require("../../middlewares");
const _utils = require("../../utils");
const _chalk = /*#__PURE__*/ _interopRequireDefault(require("chalk"));
const _commander = require("commander");
const _semver = /*#__PURE__*/ _interopRequireDefault(require("semver"));
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
const _default = (0, _commander.createCommand)().name('update').description('update a plugin').argument('<name>', 'plugin name you want to update to its latest version').action(async (name)=>{
    if (!await (0, _middlewares.checkLocation)()) return;
    _utils.logger.newLine();
    _utils.logger.spinner.start(`Updating plugin ${_chalk.default.bold(name)}...`);
    const remotePlugin = await (0, _utils.getPluginFromMonorepo)(name);
    const localPlugin = await (0, _utils.getLocalPlugin)(name);
    const projectPackageJson = await (0, _utils.getPackageJson)();
    // guards
    if (!remotePlugin) return _utils.logger.failure(`Plugin ${_chalk.default.bold(name)} does not exist in the remote.`);
    else if (!localPlugin) return _utils.logger.failure(`Plugin ${_chalk.default.bold(name)} does not exist locally.`);
    else if (remotePlugin.version === localPlugin.version) return _utils.logger.failure(`Plugin ${_chalk.default.bold(name)} is already up to date.`);
    else if (!_semver.default.satisfies(_semver.default.coerce(projectPackageJson.tscord.version), remotePlugin.tscordRequiredVersion)) return _utils.logger.failure(`Plugin ${_chalk.default.bold(`${name}@${remotePlugin.version}`)} requires tscord version ${_chalk.default.bold(remotePlugin.tscordRequiredVersion)}, but you are using ${_chalk.default.bold(projectPackageJson.tscord.version)}.`);
    // update the plugin
    const successfullyUninstalledPlugin = await (0, _utils.uninstallPlugin)(name);
    if (!successfullyUninstalledPlugin) return _utils.logger.failure(`Failed to uninstall plugin ${_chalk.default.bold(name)}.`);
    const successfullyInstalledPlugin = await (0, _utils.downloadPluginFromMonorepo)(name);
    if (!successfullyInstalledPlugin) return _utils.logger.failure(`Failed to install plugin ${_chalk.default.bold(name)}.`);
    _utils.logger.success(`Successfully updated plugin ${_chalk.default.bold(name)}.`);
});
