"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "default", {
    enumerable: true,
    get: ()=>_default
});
const _utils = require("../../utils");
const _commander = require("commander");
const _cliTable = /*#__PURE__*/ _interopRequireDefault(require("cli-table"));
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
const _default = (0, _commander.createCommand)().name('versions').description('list all the versions of a plugin').argument('<name>', 'name of the plugin you want to get info on').action(async (name)=>{
    _utils.logger.newLine();
    _utils.logger.spinner.start('Fetching info...');
    const versionsRegistry = await (0, _utils.getVersionsRegistry)();
    if (!versionsRegistry) return _utils.logger.failure('Failed to get versions registry.');
    if (versionsRegistry[name]) {
        const versions = versionsRegistry[name];
        const table = new _cliTable.default({
            head: [
                'Version',
                'TSCord required version'
            ]
        });
        for (const version of Object.keys(versions)){
            const remotePluginInfo = await (0, _utils.getPluginFromMonorepo)(name, version);
            if (!remotePluginInfo) return _utils.logger.failure(`Failed to get info on plugin ${name}@${version}.`);
            table.push([
                version,
                remotePluginInfo.tscordRequiredVersion
            ]);
        }
        _utils.logger.log(table.toString());
        _utils.logger.newLine();
    } else _utils.logger.failure('Plugin not found.');
});
