"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
function _export(target, all) {
    for(var name in all)Object.defineProperty(target, name, {
        enumerable: true,
        get: all[name]
    });
}
_export(exports, {
    downloadReleaseFromGithub: ()=>downloadReleaseFromGithub,
    downloadRepoFromGithub: ()=>downloadRepoFromGithub,
    downloadPluginFromMonorepo: ()=>downloadPluginFromMonorepo,
    downloadPlopFromGithub: ()=>downloadPlopFromGithub
});
const _fs = require("fs");
const _os = require("os");
const _path = require("path");
const _stream = require("stream");
const _util = require("util");
const _tar = /*#__PURE__*/ _interopRequireDefault(require("tar"));
const _axios = /*#__PURE__*/ _interopRequireDefault(require("axios"));
const _config = require("../config");
const _utils = require("./");
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
/**
 * @param url source url to download from
 * @param destinationPath the path where the repository will be downloaded
 * @param subDirectory if set, the subdirectory to download
 * @param strip if set, the number of directories to strip from the path
 * @returns boolean if the download was successful
 */ const downloadFromGithub = async (url, destinationPath, subDirectory = null, strip = 1)=>{
    try {
        // download the whole repository
        const pipeline = (0, _util.promisify)(_stream.Stream.pipeline);
        const tempFile = (0, _path.join)((0, _os.tmpdir)(), `temp-${Date.now()}`);
        const request = await (0, _axios.default)({
            responseType: 'stream',
            url
        });
        await pipeline(_stream.Readable.from(request.data), (0, _fs.createWriteStream)(tempFile));
        // extract the repo
        await _tar.default.x({
            cwd: destinationPath,
            file: tempFile,
            // if not null, extract only a subdirectory
            filter: (p)=>subDirectory === null || p.includes(subDirectory),
            strip
        });
        // delete the temporary tar file
        await _fs.promises.unlink(tempFile);
        return true;
    } catch (err) {
        return false;
    }
};
const downloadReleaseFromGithub = async (destinationRelativePath, source = _config.repositories.template, releaseTag = 'latest')=>{
    let url;
    if (releaseTag !== 'latest') {
        url = `https://github.com/${source.owner}/${source.repo}/archive/refs/tags/v${releaseTag}.tar.gz`;
    } else {
        // get the tag of the latest release
        try {
            const res = await _axios.default.get(`https://api.github.com/repos/${source.owner}/${source.repo}/releases/latest`);
            const latestReleaseInfo = res.data.tag_name;
            url = `https://github.com/${source.owner}/${source.repo}/archive/refs/tags/${latestReleaseInfo}.tar.gz`;
        } catch (err) {
            url = null;
        }
    }
    if (url) {
        return downloadFromGithub(url, (0, _path.resolve)() + '/' + destinationRelativePath);
    } else return false;
};
const downloadRepoFromGithub = async (destinationRelativePath, { owner , repo , branch  } = _config.repositories.plugins, subDirectory = null, strip = 1)=>{
    return downloadFromGithub(`https://codeload.github.com//${owner}/${repo}/tar.gz/${branch}`, (0, _path.resolve)() + '/' + destinationRelativePath, subDirectory, strip);
};
const downloadPluginFromMonorepo = async (pluginName, path = 'src/plugins', options = _config.repositories.plugins)=>{
    return downloadRepoFromGithub(path, options, '/plugins/' + pluginName, 2);
};
const downloadPlopFromGithub = async (destinationPath = '')=>{
    const tscordVersion = await (0, _utils.getTscordVersion)();
    return downloadRepoFromGithub(destinationPath, _config.repositories.cli, `src/plop/${tscordVersion}/cli/`, 3);
};
