"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
function _export(target, all) {
    for(var name in all)Object.defineProperty(target, name, {
        enumerable: true,
        get: all[name]
    });
}
_export(exports, {
    getPluginsFromMonorepo: ()=>getPluginsFromMonorepo,
    getPluginFromMonorepo: ()=>getPluginFromMonorepo,
    getVersionsRegistry: ()=>getVersionsRegistry
});
const _request = require("@octokit/request");
const _config = require("../config");
const _utils = require("./");
const getPluginsFromMonorepo = async ({ owner , repo  } = _config.repositories.plugins)=>{
    const response = await (0, _request.request)('GET /repos/{owner}/{repo}/contents/plugins', {
        owner,
        repo
    });
    return response.data.filter((item)=>item.type === 'dir').map((item)=>item.name);
};
const getPluginFromMonorepo = async (pluginName, version = 'latest', { owner , repo  } = _config.repositories.plugins)=>{
    const versionsRegistry = await getVersionsRegistry();
    if (!versionsRegistry) return null;
    if (version === 'latest') version = (0, _utils.getHighestVersion)(versionsRegistry[pluginName]);
    const commitHash = versionsRegistry[pluginName][version];
    if (!commitHash) return null;
    return (0, _request.request)('GET https://raw.githubusercontent.com/{owner}/{repo}/{branch}/plugins/{pluginName}/plugin.json', {
        owner,
        repo,
        pluginName,
        branch: commitHash
    }).then((response)=>({
            ...JSON.parse(response.data),
            commitHash
        })).catch((error)=>null);
};
const getVersionsRegistry = async ({ owner , repo  } = _config.repositories.plugins)=>{
    return (0, _request.request)('GET https://raw.githubusercontent.com/{owner}/{repo}/main/versions.json', {
        owner,
        repo
    }).then((response)=>JSON.parse(response.data)).catch((error)=>null);
};
