"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
function _export(target, all) {
    for(var name in all)Object.defineProperty(target, name, {
        enumerable: true,
        get: all[name]
    });
}
_export(exports, {
    getLocalPlugin: ()=>getLocalPlugin,
    uninstallPlugin: ()=>uninstallPlugin,
    getPathOfPlugin: ()=>getPathOfPlugin,
    isInTSCordProject: ()=>isInTSCordProject,
    getTscordVersion: ()=>getTscordVersion,
    isDeprecatedTscord: ()=>isDeprecatedTscord
});
const _fs = require("fs");
const _path = require("path");
const getLocalPlugin = async (pluginName)=>{
    const pluginPath = getPathOfPlugin(pluginName);
    // check if the plugin.json file of a plugin exists and get its content if it does using fs
    const pluginExists = (0, _fs.existsSync)(`${pluginPath}/plugin.json`);
    if (pluginExists) {
        const plugin = await _fs.promises.readFile(`${pluginPath}/plugin.json`, 'utf-8');
        return JSON.parse(plugin);
    } else {
        return null;
    }
};
const uninstallPlugin = async (pluginName)=>{
    try {
        const path = getPathOfPlugin(pluginName);
        await _fs.promises.rm(path, {
            recursive: true
        });
        return true;
    } catch (err) {
        return false;
    }
};
const getPathOfPlugin = (pluginName)=>{
    return (0, _path.resolve)() + '/src/plugins/' + pluginName;
};
const isInTSCordProject = async ()=>{
    return await getTscordVersion() !== null;
};
const getTscordVersion = async ()=>{
    try {
        const tscordConfig = await _fs.promises.readFile((0, _path.resolve)() + '/package.json', 'utf-8');
        const json = JSON.parse(tscordConfig);
        if (json?.tscordTemplate) return '2.0';
        else if (json?.tscord?.version) return json.tscord.version;
        else return null;
    } catch (err) {
        return null;
    }
};
const isDeprecatedTscord = async ()=>{
    const version = await getTscordVersion();
    if (!version || version === '2.0') return false;
    else return true;
};
